function [s,te,pos]=fTstat(datN,GMSn,OOMn,qq,pos,te,bte,i1,i2)
%fTstat transmission disturbance statistical overview
% description of output s
% column 01: amplitude mode for positive sideband frequency
% column 02: amplitude mode for negative sideband frequency
% column 03: amplitude standard deviation for positive sideband frequency
% column 04: amplitude standard deviation for negative sideband frequency
% column 05: phase mode for positive sideband frequency
% column 06: phase mode for negative sideband frequency
% column 07: phase standard deviation for positive sideband frequency
% column 08: phase standard deviation for negative sideband frequency
% column 09: number of samples in distribution for positive sideband frequency
% column 10: number of samples in distribution for negative sideband frequency
% column 11: delay estimate
% repeat for each GMSK transmission (so there's 3*11=33 columns)
% last few columns are MSF in the following order, amplitude mode, amplitude standard deviation, phase mode, phase standard deviation, number of samples (5 columns in total).
[fs,srs,datL,~,o2,isec,ia,ib,ed,bw,~,ofa]=DPP; % processing parameters
ll=datL*fs; nr=ll/srs;                                % length of each processing block (samples) and number of sub-blocks
[nl]=fnl(datN,ll); display(nl);                       % number of processing blocks from data file; display
nGo=11; nOo=5; nGs=length(GMSn); nOs=length(OOMn);    % number of outputs for GMSK and OOM transmissions and number of transmissions

tS=(0:datL:datL*(nl-1)); nstrt=tS*fs;  % chunk start times (in seconds and samples)

n=isec*fs; nf=2^nextpow2(2*n-1);   % number of points in frequency domain
f=linspace(0,nf-1,nf)*fs/nf;       % transform frequencies

s=zeros(nr*nl,nGo*nGs+nOo*nOs);

if i1<1||i1>nl, i1=1; end; if i2>nl||i2<i1, i2=nl; end;

for ii=i1:i2                         % iterate through selected data chunks
    display(ii); iia=1+(ii-1)*nr; iib=iia:ii*nr;     % display chunk index and calculate results index
    
    [y,~,~,ir]=frnib(datN,1,nstrt(ii),isec);     % read data
    Y=fft(y,nf); Yt=fft(y(ia-o2/2:ib+o2/2),nf);  % transforms; before and after truncating, this is a trade off between filter edge effects and influence of samples outside window
    
    [fSl,fSh,th,nS,sr]=DSF;                                      % sferic parameters
    [sf]=fFTc(f,Y,fSl,fSh,ia,ib); [bS]=fSs(sf,nS,th,ir(ia:ib));  % sferic samples
    if sum(bS)<(sr*ll)                                           % make sure there aren't too many sferics (otherwise there won't be enough samples)
        if ~isempty(OOMn)
            for ij=1:length(OOMn)                             % iterate for each OOM transmission
                iij=nGs+ij; ija=nGo*nGs+1+(ij-1)*nOo; ijb=ija:ija+nOo-1;   % indices for output vector
                [a,p,bA,pos(iij)]=fOOd(f,Yt,OOMn{ij},pos(iij),tS(ii),srs); % compute transmission disturbance
                s(iib,ijb)=fOOstats(a,p,bA,ed,bw); % calculate statistics
            end
        end
        
        if ~isempty(GMSn)
            for ij=1:length(GMSn)            % iterate for each GMSK transmission
                stN=GMSn{ij};  % specify transmission and define transmission parameters
                ija=1+(ij-1)*nGo; ijb=ija:ija+nGo-2;        % indices for output vector
                
                te1=te(ij); bt1=bte(ij); po1=pos(ij); pq=qq(ij);
                [~,a,p,bH,bL,cte,te1,bt1,po1,pq]=...
                    fGMd(f,Y,Yt,stN,te1,bt1,po1,pq,tS(ii),srs);   % compute transmission disturbance
                
                if sum(a)>0                                             % if transmitter is transmitting
                    if isnan(pos(ij)), pos(ij)=po1; end;                    % if not set before, set phase offset
                    if ~bte(ij), te(ij)=te1; bte(ij)=bt1; end;              % if not set before, set delay estimate and correlation delay estimate
                    qq(ij)=pq;                                              % save quadrant
                    bH=bH&(a>ofa); bL=bL&(a>ofa); bS=reshape(bS,srs,[]);    % remove the samples with low SNR
                    s(iib,ijb)=fGMStats(a,p,bH,bL,bS,ed,bw);                % calculate statistics
                    s(iib,ija+nGo-1)=cte;                                   % save correlation delay to output vector
                end
            end
        end
    end
end
end

function [s]=fGMStats(a,p,bH,bL,bS,ed,bw)
%fGMStats get statistical measures of amplitude and phase for binary frequency modulated transmissions
bH=bH&(~bS); bL=bL&(~bS);                                           % remove the sferic samples
nN=[sum(bH);sum(bL)].';                                             % number of samples that are used in the distribution (chunk,symbol)
ca=ed{1}+bw(1)/2; ca=ca(1:end-1); cp=ed{2}+bw(2)/2; cp=cp(1:end-1); % get centres
nr=size(a,2);
am=zeros(nr,2); as=zeros(nr,2); pm=zeros(nr,2); ps=zeros(nr,2);     % initialise variables
for ij=1:nr                                 % statistical analysis per sub chunk
    if (nN(ij,1)>(.1*nr))&&(nN(ij,2)>(.1*nr))   % if there are enough samples (else the statistics remain at the initialised value of zeros)
        ha(:,1)=histcounts(a(bH(:,ij),ij),ed{1});   % disturbance amplitude distributions
        ha(:,2)=histcounts(a(bL(:,ij),ij),ed{1});   %
        hp(:,1)=histcounts(p(bH(:,ij),ij),ed{2});   % disturbance phase distributions (radians)
        hp(:,2)=histcounts(p(bL(:,ij),ij),ed{2});   %
        
        [ma,ia]=max(ha); [mp,ip]=max(hp);                    % distribution max and bin
        ma=ma./(nN(ij,:).*bw(1)); mp=mp./(nN(ij,:).*bw(2));  % scale distribution maximums
        
        am(ij,:)=ca(ia); pm(ij,:)=cp(ip);                      % get distribution modes
        as(ij,:)=1/sqrt(2*pi)./ma; ps(ij,:)=1/sqrt(2*pi)./mp;  % compute standard deviations from maximums
    end
end
s=[am as pm ps nN];
% column description
% column 01: amplitude mode for positive sideband frequency; column 02: amplitude mode for negative sideband frequency
% column 03: amplitude standard deviation for positive sideband frequency; column 04: amplitude standard deviation for negative sideband frequency
% column 05: phase mode for positive sideband frequency; column 06: phase mode for negative sideband frequency
% column 07: phase standard deviation for positive sideband frequency; column 08: phase standard deviation for negative sideband frequency
% column 09: number of samples in distribution for positive sideband frequency; column 10: number of samples in distribution for negative sideband frequency
end

function [s]=fOOstats(a,p,bS,ed,bw)
%fOOstats get statistical measures of On Off modulated transmissions
nN=sum(~bS).';                                                      % number of samples that are used in the distribution
ca=ed{1}+bw(1)/2; ca=ca(1:end-1); cp=ed{2}+bw(2)/2; cp=cp(1:end-1); % get centres
nr=size(a,2);                                                       % number of samples per chunk
am=zeros(nr,1); as=zeros(nr,1); pm=zeros(nr,1); ps=zeros(nr,1);     % initialise variables
for ij=1:nr                                                         % statistical analysis per sub chunk
    if nN(ij)>(.1*nr)                                               % if there are enough samples (else the statistics remain at the initialised value of zeros)
        ha=histcounts(a(~bS(:,ij),ij),ed{1});                       % disturbance amplitude distributions
        hp=histcounts(p(~bS(:,ij),ij),ed{2});                       % disturbance phase distributions (radians)
        
        [ma,ia]=max(ha); [mp,ip]=max(hp);                           % distribution max and bin
        ma=ma./(nN(ij).*bw(1)); mp=mp./(nN(ij).*bw(2));             % scale distribution maximums
        
        am(ij)=ca(ia); pm(ij)=cp(ip);                               % get distribution modes
        as(ij)=1/sqrt(2*pi)./ma; ps(ij)=1/sqrt(2*pi)./mp;           % compute standard deviations from maximums
    end
end
s=[am as pm ps nN];
% column description
% column 01: amplitude mode; column 02: amplitude standard deviation
% column 03: phase mode; column 04: phase standard deviation
% column 05: number of samples in distribution
end